==> ingdao-0.0.19.tar.gz: lib/dataflow/control/dfresponse.dart <==
import 'dart:convert';
import 'package:meta/meta.dart';
import 'package:nui_web/nui_web_models.dart';
import 'package:http/http.dart' as http;
import 'dfconverter.dart';
import 'dfquery.dart';
import '../entity/dfbaseentity.dart';
import '../repository/dfdbrepository.dart';
import 'package:object_mapper/object_mapper.dart';

class DfError implements Exception {
  int code;
  String message;

  DfError({@required this.code, @required this.message});

  String errMsg() => message; 
}

class DfResponse {
  DfQuery query;
  DfError error;
  DfError onlineSyncError;
  String onlineSyncFailTrxId;
  List<Map<String,dynamic>> result;
  Map<String,dynamic> singleResult;
  int fetchCountData;

  DfResponse({this.error,this.singleResult,this.result,this.fetchCountData});

  void dataFromPlainHttpResponse(http.Response resp) {
    bool isSingleResult = resp.body != null && resp.body.trim().startsWith("{");
    if (isSingleResult) {
      singleResult = DfConverter.jsonStringToDict(resp.body);
    }
    else {
      result = DfConverter.jsonStringToDictList(resp.body);
      if (result == null)
        result = List<Map<String,dynamic>>();
    }
  }

  // List<T> renderResultToList<T extends Mappable>() {
  //   if (result != null) {
  //     List<T> arr = [];
  //     for (Map<String,dynamic> singleR in result) {
  //       arr.add(Mapper.fromJson(singleR).toObject<T>());
  //     }
  //     return arr;
  //   }
  //   return null;
  // }

  List<DfBaseEntity> renderResultToEntityList() {
    DfBaseEntity entity;
    if (query != null && query.entityJoin != null && query.entityJoin.entities != null && query.entityJoin.entities.length > 0) {
      entity = query.entityJoin.entities[0];      
    }

    if (result != null && entity != null) {
      List<DfBaseEntity> arr = [];
      for (Map<String,dynamic> singleR in result) {
        arr.add(renderResultToEntity(result: singleR));
      }
      return arr;
    }
    return null;
  }

  int renderFetchAggregateResultToInt() {
    int intResult = 0;
    if (result != null) {
      result.forEach((row) {
        row.forEach((k,v) {
          intResult = v;
        });
      });
    }
    else if (singleResult != null) {
      singleResult.forEach((k,v) {
          intResult = v;
        });
    }
    return intResult;
  }

  List<int> renderSaveDelAffectCountResultToList() {
    if (result != null) {
      List<int> arr = [];
      for (Map<String,dynamic> singleR in result) {
        arr.add(singleR[DfDbRepository.DB_UPD_JSON_FIELD]);
      }
      return arr;
    }
    return null;
  }

  // T renderResultToObject<T extends Mappable>() {
  //   if (singleResult != null) {
  //     return Mapper.fromJson(singleResult).toObject<T>();
  //   }
  //   return null;
  // }

  DfBaseEntity renderResultToEntity({Map<String,dynamic> result}) {
    DfBaseEntity entity;
    if (query != null && query.entityJoin != null && query.entityJoin.entities != null && query.entityJoin.entities.length > 0) {
      entity = query.entityJoin.entities[0];      
    }

    Map<String,dynamic> rawResult = singleResult;
    if (result != null) {
      rawResult = result;
    }
    if (entity != null && rawResult != null) {
      // print("rawResult is $rawResult");
      return entity.parseExecRawJsonResultToEntity(query.purpose, Mapper.fromJson(rawResult));      
    }
    return null;
  }

  void dataFromHttpResponse(NUIHttpResponse resp) {
    if (resp.getErrorAsEnt() != null && resp.getErrorAsEnt().status != null) {
      error = DfError(code: resp.getErrorAsEnt().status, message: resp.getErrorAsEnt().error);
    }

    if (resp.response != null) {
      result = List<Map<String,dynamic>>();
      String tStr = resp.response.trim();
      if (tStr.startsWith("[")) {
        List data = jsonDecode(tStr);
        for (Map<String,dynamic> item in data) {
          result.add(item);
        }
      }
      else {
        singleResult = jsonDecode(tStr);
      }
    }
    return;
  }
}

==> ingdao-0.0.21.tar.gz: lib/dataflow/control/dfresponse.dart <==
import 'dart:convert';
import 'package:meta/meta.dart';
import 'package:nui_web/nui_web_models.dart';
import 'package:http/http.dart' as http;
import 'dfconverter.dart';
import 'dfquery.dart';
import '../entity/dfbaseentity.dart';
import '../repository/dfdbrepository.dart';
import 'package:object_mapper/object_mapper.dart';

class DfError implements Exception {
  int code;
  String message;

  DfError({@required this.code, @required this.message});

  String errMsg() => message; 
}

class DfResponse {
  DfQuery query;
  DfError error;
  DfError onlineSyncError;
  String onlineSyncFailTrxId;
  List<Map<String,dynamic>> result;
  Map<String,dynamic> singleResult;
  int fetchCountData;

  DfResponse({this.error,this.singleResult,this.result,this.fetchCountData});

  void dataFromPlainHttpResponse(http.Response resp) {
    bool isSingleResult = resp.body != null && resp.body.trim().startsWith("{");
    if (isSingleResult) {
      singleResult = DfConverter.jsonStringToDict(resp.body);
    }
    else {
      result = DfConverter.jsonStringToDictList(resp.body);
      if (result == null)
        result = List<Map<String,dynamic>>();
    }
  }

  // List<T> renderResultToList<T extends Mappable>() {
  //   if (result != null) {
  //     List<T> arr = [];
  //     for (Map<String,dynamic> singleR in result) {
  //       arr.add(Mapper.fromJson(singleR).toObject<T>());
  //     }
  //     return arr;
  //   }
  //   return null;
  // }

  List<DfBaseEntity> renderResultToEntityList() {
    DfBaseEntity entity;
    if (query != null && query.entityJoin != null && query.entityJoin.entities != null && query.entityJoin.entities.length > 0) {
      entity = query.entityJoin.entities[0];      
    }

    if (result != null && entity != null) {
      List<DfBaseEntity> arr = [];
      for (Map<String,dynamic> singleR in result) {
        arr.add(renderResultToEntity(result: singleR));
      }
      return arr;
    }
    return null;
  }

  int renderFetchAggregateResultToInt() {
    int intResult = 0;
    if (result != null) {
      result.forEach((row) {
        row.forEach((k,v) {
          intResult = v;
        });
      });
    }
    else if (singleResult != null) {
      singleResult.forEach((k,v) {
          intResult = v;
        });
    }
    return intResult;
  }

  List<int> renderSaveDelAffectCountResultToList() {
    if (result != null) {
      List<int> arr = [];
      for (Map<String,dynamic> singleR in result) {
        arr.add(singleR[DfDbRepository.DB_UPD_JSON_FIELD]);
      }
      return arr;
    }
    return null;
  }

  // T renderResultToObject<T extends Mappable>() {
  //   if (singleResult != null) {
  //     return Mapper.fromJson(singleResult).toObject<T>();
  //   }
  //   return null;
  // }

  DfBaseEntity renderResultToEntity({Map<String,dynamic> result}) {
    DfBaseEntity entity;
    if (query != null && query.entityJoin != null && query.entityJoin.entities != null && query.entityJoin.entities.length > 0) {
      entity = query.entityJoin.entities[0];      
    }

    Map<String,dynamic> rawResult = singleResult;
    if (result != null) {
      rawResult = result;
    }
    if (entity != null && rawResult != null) {
      // print("rawResult is $rawResult");
      return entity.parseExecRawJsonResultToEntity(query.purpose, Mapper.fromJson(rawResult));      
    }
    return null;
  }

  void dataFromHttpResponse(NUIHttpResponse resp) {
    if (!resp.success) {
      error = DfError(code: resp.code, message: resp.message);
    }

    if (resp.response != null) {
      result = List<Map<String,dynamic>>();
      String tStr = resp.response.trim();
      if (tStr.startsWith("[")) {
        List data = jsonDecode(tStr);
        for (Map<String,dynamic> item in data) {
          result.add(item);
        }
      }
      else {
        singleResult = jsonDecode(tStr);
      }
    }
    return;
  }
}
